@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -11,15 +14,16 @@ import typing_extensions
 from typeguard import check_type
 
 import aws_cdk._jsii
+import aws_cdk.integ_tests_alpha._jsii
 import aws_solutions_constructs.aws_kinesis_firehose_s3._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-kinesisfirehose",
-    "2.34.0",
+    "2.57.0",
     __name__[0:-6],
-    "aws-lambda-kinesisfirehose@2.34.0.jsii.tgz",
+    "aws-lambda-kinesisfirehose@2.57.0.jsii.tgz",
 )
 
 __all__ = [
